@@ -1,5 +1,5 @@
 #include <Rcpp.h>
-#include <math.h>
+#include <cmath>
 using namespace Rcpp;
 
 // [[Rcpp::export]]
@@ -40,10 +40,12 @@ NumericMatrix HellingerMat(NumericMatrix A){
         double result = 0.0;
         
         for(int i = 0; i < cols; i++){
-          result = result + (sqrt(A2(j , i)) - sqrt(A2(k , i))) * (sqrt(A2(j , i)) - sqrt(A2(k , i)));
+          result = result + (std::sqrt(double(A2(j , i))) - 
+            std::sqrt(double(A2(k , i)))) * (std::sqrt(double(A2(j , i))) - 
+            std::sqrt(double(A2(k , i))));
         }
                 
-        answer(j , k) = sqrt(0.5) * sqrt(result);
+        answer(j , k) = std::sqrt(double(0.5)) * std::sqrt(result);
         
       }
     }
